pub struct TransactionTreeHash(pub Hash);Tuple Fields
0: HashTrait Implementations
Sourceimpl AsRef<[u8]> for TransactionTreeHash
impl AsRef<[u8]> for TransactionTreeHash
Sourceimpl AsRef<Hash> for TransactionTreeHash
impl AsRef<Hash> for TransactionTreeHash
Sourceimpl<X: CustomValueKind> Categorize<X> for TransactionTreeHash
impl<X: CustomValueKind> Categorize<X> for TransactionTreeHash
fn value_kind() -> ValueKind<X>
Sourceimpl Clone for TransactionTreeHash
impl Clone for TransactionTreeHash
Sourcefn clone(&self) -> TransactionTreeHash
fn clone(&self) -> TransactionTreeHash
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionTreeHash
impl Debug for TransactionTreeHash
Sourceimpl<D: Decoder<X>, X: CustomValueKind> Decode<X, D> for TransactionTreeHash
impl<D: Decoder<X>, X: CustomValueKind> Decode<X, D> for TransactionTreeHash
Sourcefn decode_body_with_value_kind(
decoder: &mut D,
value_kind: ValueKind<X>,
) -> Result<Self, DecodeError>
fn decode_body_with_value_kind( decoder: &mut D, value_kind: ValueKind<X>, ) -> Result<Self, DecodeError>
Decodes the type from the decoder, which should match a preloaded value kind. Read more
Sourceimpl<C: CustomTypeKind<RustTypeId>> Describe<C> for TransactionTreeHash
impl<C: CustomTypeKind<RustTypeId>> Describe<C> for TransactionTreeHash
Sourceconst TYPE_ID: RustTypeId
const TYPE_ID: RustTypeId
The
TYPE_ID should give a unique identifier for its SBOR schema type.
An SBOR schema type capture details about the SBOR payload, how it should be interpreted, validated and displayed. Read moreSourcefn type_data() -> TypeData<C, RustTypeId>
fn type_data() -> TypeData<C, RustTypeId>
Returns the local schema for the given type. Read more
Sourcefn add_all_dependencies(aggregator: &mut TypeAggregator<C>)
fn add_all_dependencies(aggregator: &mut TypeAggregator<C>)
For each type referenced in
get_local_type_data, we need to ensure that the type and all of its own references
get added to the aggregator. Read moreSourceimpl<E: Encoder<X>, X: CustomValueKind> Encode<X, E> for TransactionTreeHash
impl<E: Encoder<X>, X: CustomValueKind> Encode<X, E> for TransactionTreeHash
Sourcefn encode_value_kind(&self, encoder: &mut E) -> Result<(), EncodeError>
fn encode_value_kind(&self, encoder: &mut E) -> Result<(), EncodeError>
Encodes the SBOR value’s kind to the encoder
Sourcefn encode_body(&self, encoder: &mut E) -> Result<(), EncodeError>
fn encode_body(&self, encoder: &mut E) -> Result<(), EncodeError>
Encodes the SBOR body of the type to the encoder. Read more
Sourceimpl From<Hash> for TransactionTreeHash
impl From<Hash> for TransactionTreeHash
Sourceimpl From<TransactionTreeHash> for Hash
impl From<TransactionTreeHash> for Hash
Sourcefn from(value: TransactionTreeHash) -> Self
fn from(value: TransactionTreeHash) -> Self
Converts to this type from the input type.
Sourceimpl Hash for TransactionTreeHash
impl Hash for TransactionTreeHash
Sourceimpl IsHash for TransactionTreeHash
impl IsHash for TransactionTreeHash
Sourceimpl Ord for TransactionTreeHash
impl Ord for TransactionTreeHash
Sourcefn cmp(&self, other: &TransactionTreeHash) -> Ordering
fn cmp(&self, other: &TransactionTreeHash) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TransactionTreeHash
impl PartialEq for TransactionTreeHash
Sourceimpl PartialOrd for TransactionTreeHash
impl PartialOrd for TransactionTreeHash
Sourceimpl<X: CustomValueKind> SborEnum<X> for TransactionTreeHash
impl<X: CustomValueKind> SborEnum<X> for TransactionTreeHash
fn get_discriminator(&self) -> u8
fn get_length(&self) -> usize
Sourceimpl<X: CustomValueKind> SborTuple<X> for TransactionTreeHash
impl<X: CustomValueKind> SborTuple<X> for TransactionTreeHash
fn get_length(&self) -> usize
impl Copy for TransactionTreeHash
impl Eq for TransactionTreeHash
impl StructuralPartialEq for TransactionTreeHash