CallMethod

Struct CallMethod 

pub struct CallMethod {
    pub component_address: SimulatorComponentAddress,
    pub method_name: String,
    pub arguments: Vec<String>,
    pub proofs: Option<Vec<String>>,
    pub network: Option<String>,
    pub manifest: Option<PathBuf>,
    pub signing_keys: Option<String>,
    pub trace: bool,
}
Call a method

Fields

component_address: SimulatorComponentAddress

The component that the method belongs to

method_name: String

The method name

arguments: Vec<String>

The call arguments, such as “5”, “hello”, “<resource_address>:” and “<resource_address>:<nf_local_id1>,<nf_local_id2>”

proofs: Option<Vec<String>>

The proofs to add to the auth zone, in form of “<resource_address>:” or “<resource_address>:<nf_local_id1>,<nf_local_id2>”

network: Option<String>

The network to use when outputting manifest, [simulator | adapanet | nebunet | mainnet]

manifest: Option<PathBuf>

Output a transaction manifest without execution

signing_keys: Option<String>

The private keys used for signing, separated by comma

trace: bool

Turn on tracing

Implementations

Source

impl CallMethod

pub fn run<O: Write>(&self, out: &mut O) -> Result<(), String>

pub fn add_call_method_instruction_with_schema( &self, builder: ManifestBuilder, address_bech32_decoder: &AddressBech32Decoder, component_address: ComponentAddress, method_name: String, args: Vec<String>, account: Option<ComponentAddress>, ) -> Result<ManifestBuilder, Error>

Calls a method.

The implementation will automatically prepare the arguments based on the method SCHEMA, including resource buckets and proofs.

If an Account component address is provided, resources will be withdrawn from the given account; otherwise, they will be taken from transaction worktop.