CoverageError

Enum CoverageError 

pub enum CoverageError {
Show 14 variants FailedToResolvePackagePath, PathDoesntExist(PathBuf), CargoMetadataError(Error), WorkspacesNotPermitted, NoPackagesFound, CommandFailedToRun(Error), StdoutIsNotValidUtf8(FromUtf8Error), CommandNotFound(Vec<String>), BuildError(BuildError), TestError(TestError), IoError(Error), ClangFailed(String), LlvmProfdataFailed(String), LlvmCovFailed(String),
}
The error type used in coverage.

Variants



FailedToResolvePackagePath

We’ve been unable to resolve the path of the package. It could be due to the user providing an invalid path or due to us not being able to get the current working directory or due to us failing to canonicalize the path of the package.



PathDoesntExist(PathBuf)

One of the paths that are required for coverage was checked for and it doesn’t exist.



CargoMetadataError(Error)

An error occurred when we tried to get the cargo metadata of the package.



WorkspacesNotPermitted

Found multiple packages when we got the metadata leading us to know that this is a workspace which is currently not permitted.



NoPackagesFound

Could not find any packages when we got the cargo metadata and therefore there is nothing that we can perform.



CommandFailedToRun(Error)

We ran a command but it failed to run or failed during waiting.



StdoutIsNotValidUtf8(FromUtf8Error)

One of the commands produced stdout output that wasn’t valid utf-8



CommandNotFound(Vec<String>)

One of the commands that we look for were not found in the system.



BuildError(BuildError)

An error was encountered when trying to build the package.



TestError(TestError)

An error was encountered when trying to test the package.



IoError(Error)

A generic IO error.



ClangFailed(String)

An error was encountered when running the clang command



LlvmProfdataFailed(String)

An error was encountered when running the llvm-profdata command



LlvmCovFailed(String)

An error was encountered when running the llvm-cov command