pub struct CallFunction {
pub package_address: SimulatorPackageAddress,
pub blueprint_name: String,
pub function_name: String,
pub arguments: Vec<String>,
pub proofs: Option<Vec<String>>,
pub network: Option<String>,
pub manifest: Option<PathBuf>,
pub signing_keys: Option<String>,
pub trace: bool,
}Expand description
Call a function
Fields
package_address: SimulatorPackageAddressThe package which the function belongs to
blueprint_name: StringThe name of the blueprint which the function belongs to
function_name: StringThe function name
arguments: Vec<String>The call arguments, such as “5”, “hello”, “<resource_address>:
proofs: Option<Vec<String>>The proofs to add to the auth zone, in form of “<resource_address>:
network: Option<String>The network to use when outputting manifest, [simulator | adapanet | nebunet | mainnet]
manifest: Option<PathBuf>Output a transaction manifest without execution
signing_keys: Option<String>The private keys used for signing, separated by comma
trace: boolTurn on tracing
Implementations
Sourceimpl CallFunction
impl CallFunction
pub fn run<O: Write>(&self, out: &mut O) -> Result<(), String>
Sourcepub fn add_call_function_instruction_with_schema(
&self,
builder: ManifestBuilder,
address_bech32_decoder: &AddressBech32Decoder,
package_address: PackageAddress,
blueprint_name: String,
function_name: String,
args: Vec<String>,
account: Option<ComponentAddress>,
) -> Result<ManifestBuilder, Error>
pub fn add_call_function_instruction_with_schema( &self, builder: ManifestBuilder, address_bech32_decoder: &AddressBech32Decoder, package_address: PackageAddress, blueprint_name: String, function_name: String, args: Vec<String>, account: Option<ComponentAddress>, ) -> Result<ManifestBuilder, Error>
Calls a function.
The implementation will automatically prepare the arguments based on the function SCHEMA, including resource buckets and proofs.
If an Account component address is provided, resources will be withdrawn from the given account; otherwise, they will be taken from transaction worktop.